climatestatistics: Reports observed climate statistics
Description
Helper function to report community climate statistics for the real community, i.e. not corrected for any null model.Usage
climatestatistics(object)
Value
A named list:meanNichesA dataframe with columns corresponding to climate axes, and one row for each species in the community. Each observation is the mean climate niche of that species at t1.inferredClimateA vector with names corresponding to climate axes, representing the inferred climate determined by overlapping niches of all species in the community at t1.observedClimateA vector with names corresponding to climate axes, representing the observed climate at t2.volumeMagnitudeA number representing the climate volume at t1 (Delta)mismatchMagnitudeA number representing the magnitude of the climate mismatch at t1 relative to the climate at t2 (Lambda)mismatchDirectionsA vector with names corresponding to climate axes, representing the climate mismatch projected along each axis at t1 relative to the climate at t2.